@@ -41,6 +41,7 @@ from .literals import (
     S3ConnectorOperatorType,
     S3InputFileTypeType,
     SalesforceConnectorOperatorType,
+    SalesforceDataTransferApiType,
     SAPODataConnectorOperatorType,
     ScheduleFrequencyTypeType,
     ServiceNowConnectorOperatorType,
@@ -385,6 +386,7 @@ SalesforceMetadataTypeDef = TypedDict(
     "SalesforceMetadataTypeDef",
     {
         "oAuthScopes": List[str],
+        "dataTransferApis": List[SalesforceDataTransferApiType],
     },
     total=False,
 )
@@ -1069,6 +1071,7 @@ _OptionalSalesforceSourcePropertiesTypeDef = TypedDict(
     {
         "enableDynamicFieldUpdate": bool,
         "includeDeletedRecords": bool,
+        "dataTransferApi": SalesforceDataTransferApiType,
     },
     total=False,
 )
@@ -1646,6 +1649,7 @@ _OptionalSalesforceDestinationPropertiesTypeDef = TypedDict(
         "idFieldNames": Sequence[str],
         "errorHandlingConfig": ErrorHandlingConfigTypeDef,
         "writeOperationType": WriteOperationTypeType,
+        "dataTransferApi": SalesforceDataTransferApiType,
     },
     total=False,
 )
